@@ -88,7 +88,7 @@ init_tokens ()
     tokenize (ADHOC_TREF_,  "adhoc_tref", FLOAT_PARAM)
     tokenize (PC_FREQ_,     "pc_freqs"  , CHAN_PARAM)
     tokenize (USE_SAMPLES_, "use_samples",INT_PARAM)
-    tokenize (PASSBAND_,    "passband",   VECTOR_FLOAT_PARAM)
+    tokenize (PASSBAND_,    "passband",   TWO_FLOAT_PARAM)
     tokenize (T_COHERE_,    "t_cohere",   FLOAT_PARAM)
     tokenize (IONOSPHERE_,  "ionosphere", FLOAT_PARAM)
     tokenize (DELAY_OFFS_,  "delay_offs", CHAN_PARAM)
@@ -118,5 +118,9 @@ init_tokens ()
     tokenize (MBD_ANCHOR_,  "mbd_anchor", INT_PARAM)
     tokenize (MODEL_,       "model",      INT_CONST + MODEL)
     tokenize (SBD_,         "sbd",        INT_CONST + SBD)
+    tokenize (SAMPLER_DELAY_L_,"sampler_delay_l", VECTOR_FLOAT_PARAM)
+    tokenize (SAMPLER_DELAY_R_,"sampler_delay_r", VECTOR_FLOAT_PARAM)
+    tokenize (SAMPLER_DELAY_X_,"sampler_delay_x", VECTOR_FLOAT_PARAM)
+    tokenize (SAMPLER_DELAY_Y_,"sampler_delay_y", VECTOR_FLOAT_PARAM)
     }
 
