@@ -158,6 +158,8 @@ int *npass;
         for (j=0; j<MAXFREQ; j++) 
             p->pass_data[j].data_alloc = FALSE;
         clear_pass (p);
+        for (j=0; j<4; j++)
+            p->pprods_present[j] = 0;
 
         p->pol = gptab[*npass].pol;
         p->npols = gptab[*npass].npols;
@@ -240,7 +242,7 @@ int *npass;
                     {
                     fc->trk_lcp[n][k] = corel[j].trk_lcp[n][k];
                     fc->trk_rcp[n][k] = corel[j].trk_rcp[n][k];
-                    msg ("trk_lcp[%d][%d] %d  _rcp %d", 0,
+                    msg ("trk_lcp[%d][%d] %d  _rcp %d", -3,
                          n,k,fc->trk_lcp[n][k], fc->trk_rcp[n][k]);
                     fc->mean_lcp_trk_err[n][k] = corel[j].mean_lcp_trk_err[n][k];
                     fc->mean_rcp_trk_err[n][k] = corel[j].mean_rcp_trk_err[n][k];
