@@ -20,7 +20,7 @@ struct token_struct
    };
 
 
-#define MAX_TOKENS   100   /* Increase if many more tokens added */
+#define MAX_TOKENS   105   /* Increase if many more tokens added */
 #define MAX_STATES    20   /*     "    "   "    "   states   "   */
 
 
@@ -123,6 +123,10 @@ struct token_struct
 #define PC_PHASE_Y_      93
 #define PC_DELAY_X_      94
 #define PC_DELAY_Y_      95
+#define SAMPLER_DELAY_L_ 96
+#define SAMPLER_DELAY_R_ 97
+#define SAMPLER_DELAY_X_ 98
+#define SAMPLER_DELAY_Y_ 99
 
 
         /* Definitions of token categories */
